==> dasu_4.11.jar: edu/northwestern/dasu/sandbox/mainSandboxedProcess.java <==
/**
 * Dasu Project
 *
 * File:         StartActiveEngine.java
 * RCS:          $Id: StartActiveEngine.java,v 1.0 Jul 16, 2012 12:51:20 PM mas939 Exp $
 * Description:  StartActiveEngine class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jul 16, 2012 at 12:51:20 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.sandbox
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.sandbox;

import java.io.File;
import java.io.IOException;
import java.net.InetSocketAddress;
import java.net.MalformedURLException;
import java.net.ServerSocket;
import java.net.Socket;
import java.net.URL;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RMISecurityManager;
import java.rmi.RemoteException;
import java.rmi.server.RMISocketFactory;
import java.security.Policy;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map.Entry;

import edu.northwestern.dasu.drools.RuleBasedEngine;
import edu.northwestern.dasu.measurement.types.SourceType;
import edu.northwestern.dasu.sandbox.applet.RemoteAMCPolicy;
import edu.northwestern.dasu.sandbox.applet.RmiAMEServerInterface;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The SandboxedActiveEngine class ...
 */
public class mainSandboxedProcess {

	private final static java.util.logging.Logger LOGGER = java.util.logging.Logger.getLogger("edu.northwestern.dasu");
	private static edu.northwestern.dasu.sandbox.AppletClassLoader classLoader = null;
	private static Runnable profiler = null;
	private static Thread profilerThread = null;
	private static HashMap<String, SandboxedActiveEngineClass> ActiveEngines = new HashMap<String, SandboxedActiveEngineClass>();
	private static HashMap<String, ArrayList<String>> ActiveEnginesRequest = new HashMap<String, ArrayList<String>>();
	private static RmiAMEServerInterface AMEServer = null;
	private static Integer maxAMExperiments = 1;
	private static String codesourceRmi = null;		
	public static Object notify = new Object();
 	
	public static RuleBasedEngine getEngine(SourceType engineId) {
		
		System.out.println("\ngetEngine: " + engineId + " " + ActiveEngines);
		if ( ActiveEngines.containsKey(engineId.toString() )) {
			return ActiveEngines.get(engineId.toString()).getAMEngine();
		}
		
		return null;
	}
	
	public static void initClassLoader() throws IOException {

		//String path = 
		//		"/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/commons-jxpath-1.1.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/dnsjava-2.1.1.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/sbbi-upnplib-1.0.4.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/drools/antlr-2.7.6.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/drools/antlr-runtime-3.1.3.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/drools/drools-api-5.1.1.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/drools/drools-core-5.1.1.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/drools/janino.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/drools/mvel2-2.0.16.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/drools/xstream-1.3.1.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/drools/drools-compiler-5.1.1.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/swt.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/bully/lib/zookeeper-3.3.2.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/jline-0.9.94.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/log4j-1.2.15.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/zookeeper-3.3.5.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/commons-net-2.0.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/ant.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/ant-launcher.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/Vuze_4721-06.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/transloader-0.4.jar:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/libs/ant-commons-logging-1.6.2.jar";
		//
		//classLoader = new edu.northwestern.dasu.sandbox.AppletClassLoader(new URL("file:/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/Dasu-Client/bin/"));
		
		String path = System.getProperty("java.class.path");
        System.out.println("*" + path + "*");
        
		ArrayList<URL> urls = new ArrayList();			
		for ( String url : path.split(File.pathSeparator)) {
			
			try {
				System.out.println("*" + url + "*");
				urls.add(new URL("file:" + url));
				if ( classLoader == null )
					classLoader = new edu.northwestern.dasu.sandbox.AppletClassLoader(new URL("file:" + url));
				else
					classLoader.addJar(url);
			}
			catch (Exception e) {
				System.out.println("*" + url + "*" + e.getLocalizedMessage());
			}
		}
		
	}
	
	public static void initializeAMEServer() {
		
		try {
			
			System.getProperties().put("java.rmi.server.useCodebaseOnly", "true");
			System.getProperties().put("java.rmi.server.codebase", codesourceRmi);
			System.out.println(System.getProperties().get("java.rmi.server.codebase"));
			System.getProperties().put("java.rmi.server.hostname", "127.0.0.1");
			
			AMEServer = (RmiAMEServerInterface) Naming.lookup("rmi://localhost/RmiAMEServer");
			
			Policy.setPolicy(new RemoteAMCPolicy());
			System.setSecurityManager(new RMISecurityManager());

		} catch (MalformedURLException e) {
			e.printStackTrace();
		} catch (RemoteException e) {
			e.printStackTrace();
		} catch (NotBoundException e) {
			e.printStackTrace();
		}
		
	}
	
	public static void initializeProfiler() throws IOException {		
		
		profiler = new SandboxedResourceProfiler();
		profilerThread = new Thread(profiler);
		profilerThread.setName("DasuSandboxedResourceProfiler");
		profilerThread.start();
		
	}
	
	public static String getAvailableAME() {
		
		for ( SourceType st : SourceType.values()) {							
			if ( st.equals(SourceType.NULL) || st.equals(SourceType.RE) )
				continue;

			if ( !ActiveEngines.containsKey(st.toString()) && !ActiveEnginesRequest.containsKey(st.toString()) )
				return st.toString();
				
		}
		
		return null;
	}
	
	public static void main(String[] args) {
				
		try {
						
			RMISocketFactory.setSocketFactory( new RMISocketFactory()
	        {
				
				//shutdown after two minutes
				int timeoutMillis = 120*1000;
	            public Socket createSocket( String host, int port ) throws IOException {
	                Socket socket = new Socket();
	                socket.setSoTimeout( timeoutMillis );
	                socket.setSoLinger( false, 0 );
	                socket.connect( new InetSocketAddress( host, port ), timeoutMillis );
	                return socket;
	            }

	            public ServerSocket createServerSocket( int port ) throws IOException {
	                return new ServerSocket( port );
	            }
	        } );
			
			maxAMExperiments = Integer.parseInt(args[0]);
			codesourceRmi = args[1];
			
			initClassLoader();
			initializeProfiler();
			initializeAMEServer();			
			
			//isActive = true;
			while (AMEServer.isServerAlive()) {
			
				String st = null;
				while ( ( st = getAvailableAME() ) != null && 
						( ActiveEnginesRequest.size() + ActiveEngines.size() < maxAMExperiments) ) {
					
					System.out.println(st);
					final String engineId = st.toString();
					Thread t = new Thread() {
													
						public void run() {					
							try {	
								
								ArrayList<String> ret = AMEServer.getAMExperiment(engineId);
								LOGGER.info("AME: " + ret);
								if ( ret != null ) {
									
									LOGGER.info("AME: Experiment received! " + ret);
									synchronized(ActiveEnginesRequest) {
										ActiveEnginesRequest.put(engineId, ret);
									}
									
								}
								else{

									synchronized(ActiveEnginesRequest) {
										ActiveEnginesRequest.remove(engineId);
									}

								}
								
								synchronized(notify) {
									notify.notify();
								}								

							} catch (RemoteException e) {
								e.printStackTrace();
							}
							
						}
					};
					
					ActiveEnginesRequest.put(st, null);
					t.start();
					
				}

				synchronized(notify) {
					notify.wait(25*1000);
				}

				Iterator<Entry<String, ArrayList<String>>> iter = ActiveEnginesRequest.entrySet().iterator();
				while ( iter.hasNext() ) {
					Entry<String, ArrayList<String>> entry = iter.next();
					if ( entry.getValue() != null ) {
						
						String engineId = entry.getKey();
						String[] arguments = entry.getValue().toArray(new String[entry.getValue().size()]);
						
						try {
							//remove policy constraints
							Policy.getPolicy().refresh();
							
							//System.out.println("do something! ActiveEnginesRequest " + engineId );
							Class<?> c = null;			
							c = classLoader.loadClass("edu.northwestern.dasu.sandbox.applet.SandboxedActiveEngine");						
							SandboxedActiveEngineClass runnable = (SandboxedActiveEngineClass) 
									c.getConstructor(String[].class).newInstance(new Object[]{arguments}); 
							Thread t = new Thread(runnable);								
							ActiveEngines.put(engineId, runnable);
							
							//restart policy constraints
							Policy.getPolicy().refresh();
							
							t.start();
						}
						catch (Exception e) {
							//e.printStackTrace();						
							LOGGER.info("AME: Downloaded experiment signature could not be verified, abort...");
							AMEServer.AMECompleted(engineId);
						}
						
						iter.remove();
						
					}
				}			
				
				synchronized(notify) {
					notify.wait(5*1000);
				}

				
				Iterator<Entry<String, SandboxedActiveEngineClass>> iterAE = ActiveEngines.entrySet().iterator();
				while ( iterAE.hasNext() ) {
					Entry<String, SandboxedActiveEngineClass> entry = iterAE.next();
					if ( !entry.getValue().isAlive() ) {
						iterAE.remove();
						AMEServer.AMECompleted(entry.getKey());
					}
					
				}

				System.out.println(ActiveEngines);
				System.out.println(ActiveEnginesRequest);

				
			}
			
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		System.out.println("Server is not online, goodbye...");
		System.exit(0);
		
	}
	
}

==> dasu_5.1.jar: edu/northwestern/dasu/sandbox/mainSandboxedProcess.java <==
/**
 * Dasu Project
 *
 * File:         StartActiveEngine.java
 * RCS:          $Id: StartActiveEngine.java,v 1.0 Jul 16, 2012 12:51:20 PM mas939 Exp $
 * Description:  StartActiveEngine class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jul 16, 2012 at 12:51:20 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.sandbox
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.sandbox;

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.net.InetSocketAddress;
import java.net.MalformedURLException;
import java.net.ServerSocket;
import java.net.Socket;
import java.net.URL;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RMISecurityManager;
import java.rmi.RemoteException;
import java.rmi.server.RMISocketFactory;
import java.security.Policy;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map.Entry;

import edu.northwestern.dasu.DasuConfiguration;
import edu.northwestern.dasu.drools.ReportableFact;
import edu.northwestern.dasu.drools.RuleBasedEngine;
import edu.northwestern.dasu.measurement.types.SourceType;
import edu.northwestern.dasu.sandbox.applet.RemoteAMCPolicy;
import edu.northwestern.dasu.sandbox.applet.RmiAMEServerInterface;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The SandboxedActiveEngine class ...
 */
public class mainSandboxedProcess {

	private final static java.util.logging.Logger LOGGER = java.util.logging.Logger.getLogger("edu.northwestern.dasu");
	private static edu.northwestern.dasu.sandbox.AppletClassLoader classLoader = null;
	private static SandboxedResourceProfiler profiler = null;
	private static Thread profilerThread = null;
	private static HashMap<String, SandboxedActiveEngineClass> ActiveEngines = new HashMap<String, SandboxedActiveEngineClass>();
	private static HashMap<String, ArrayList<String>> ActiveEnginesRequest = new HashMap<String, ArrayList<String>>();
	private static RmiAMEServerInterface AMEServer = null;
	private static Integer maxAMExperiments = 1;
	private static String codesourceRmi = null;		
	public static Object notify = new Object();
	public static Boolean shutdown = false;
 	
	public static RuleBasedEngine getEngine(SourceType engineId) {
		
		System.out.println("\n getEngine: " + engineId + " " + ActiveEngines);
		if ( ActiveEngines.containsKey(engineId.toString() )) {
			return ActiveEngines.get(engineId.toString()).getAMEngine();
		}
		
		return null;
	}
	
	public static void initClassLoader() throws IOException {

		String path = System.getProperty("java.class.path");
        System.out.println("*" + path + "*");
        
		ArrayList<URL> urls = new ArrayList<URL>();			
		for ( String url : path.split(File.pathSeparator)) {
			
			try {
				System.out.println("*" + url + "*");
				urls.add(new URL("file:" + url));
				if ( classLoader == null )
					classLoader = new edu.northwestern.dasu.sandbox.AppletClassLoader(new URL("file:" + url),
							ClassLoader.getSystemClassLoader());
				else
					classLoader.addJar(url);
			}
			catch (Exception e) {
				System.out.println("*" + url + "*" + e.getLocalizedMessage());
			}
		}
		
	}
	
	public static void initializeAMEServer() {
		
		try {
			
			System.getProperties().put("java.rmi.server.useCodebaseOnly", "true");
			System.getProperties().put("java.rmi.server.codebase", codesourceRmi);
			System.getProperties().put("java.rmi.server.hostname", "127.0.0.1");
			System.out.println("java.rmi.server.hostname: " + System.getProperties().get("java.rmi.server.hostname"));
			System.out.println("java.rmi.server.codebase: " + System.getProperties().get("java.rmi.server.codebase"));			
			
			AMEServer = (RmiAMEServerInterface) Naming.lookup("rmi://localhost/RmiAMEServer");
			Policy.setPolicy(new RemoteAMCPolicy());
			System.setSecurityManager(new RMISecurityManager());
			
			LOGGER.info("AME: AMEServer: " + AMEServer);

			
		} catch (MalformedURLException e) {
			e.printStackTrace();
		} catch (RemoteException e) {
			e.printStackTrace();
		} catch (NotBoundException e) {
			e.printStackTrace();
		}
		
	}
	
	public static void initializeProfiler() throws IOException {		
		
		profiler = 	new SandboxedResourceProfiler(				
				DasuConfiguration.getInstance().getResourceProfilerRecordInterval(), //1
				DasuConfiguration.getInstance().getResourceProfilerLimitUtilizationInterval(), //5
				DasuConfiguration.getInstance().getMaxAllowedCpuUtilizationProfiler(), //0.001f
				new String[]{""});

		profilerThread = new Thread(profiler);
		profilerThread.setName("DasuSandboxedResourceProfiler");
		profilerThread.start();
		
	}
	
	public static String getAvailableAME() {
		
		for ( SourceType st : SourceType.values()) {							
			if ( st.equals(SourceType.NULL) || st.equals(SourceType.RE) )
				continue;

			if ( !ActiveEngines.containsKey(st.toString()) && !ActiveEnginesRequest.containsKey(st.toString()) )
				return st.toString();
				
		}
		
		return null;
	}		
	
	public static void main(String[] args) {
				
		try {
						
			RMISocketFactory.setSocketFactory( new RMISocketFactory()
	        {
				
				//shutdown after two minutes
				int timeoutMillis = 120*1000;
	            public Socket createSocket( String host, int port ) throws IOException {
	                Socket socket = new Socket();
	                socket.setSoTimeout( timeoutMillis );
	                socket.setSoLinger( false, 0 );
	                socket.connect( new InetSocketAddress( host, port ), timeoutMillis );
	                return socket;
	            }

	            public ServerSocket createServerSocket( int port ) throws IOException {
	                return new ServerSocket( port );
	            }
	        } );
			
			maxAMExperiments = Integer.parseInt(args[0]);
			codesourceRmi = args[2] + " " + args[1];
			
			initClassLoader();
			initializeProfiler();
			initializeAMEServer();
			
			//isActive = true;
			while (AMEServer.isServerAlive() && !isShutdown()) {
			
				String st = null;
				while ( ( st = getAvailableAME() ) != null && 
						( ActiveEnginesRequest.size() + ActiveEngines.size() < maxAMExperiments) ) {
					
					LOGGER.info("AME: Available SourceType: " + st);
					final String engineId = st.toString();
					Thread t = new Thread() {
													
						public void run() {					
							try {	
								
								ArrayList<String> ret = AMEServer.getAMExperiment(engineId);
								LOGGER.info("AME: " + ret);
								if ( ret != null ) {
									
									LOGGER.info("AME: Experiment received! " + ret);
									synchronized(ActiveEnginesRequest) {
										ActiveEnginesRequest.put(engineId, ret);
									}
									
								}
								else{

									synchronized(ActiveEnginesRequest) {
										ActiveEnginesRequest.remove(engineId);
									}

								}
								
								synchronized(notify) {
									notify.notify();
								}								

							} catch (RemoteException e) {
								e.printStackTrace();
							}
							
						}
					};
					
					ActiveEnginesRequest.put(st, null);
					t.start();
					
				}

				synchronized(notify) {
					notify.wait(25*1000);
				}

				Iterator<Entry<String, ArrayList<String>>> iter = ActiveEnginesRequest.entrySet().iterator();
				while ( iter.hasNext() ) {
					Entry<String, ArrayList<String>> entry = iter.next();
					if ( entry.getValue() != null ) {
						
						String engineId = entry.getKey();
						String[] arguments = entry.getValue().toArray(new String[entry.getValue().size()]);
						
						try {
							//remove policy constraints
							Policy.getPolicy().refresh();
							
							//System.out.println("do something! ActiveEnginesRequest " + engineId );
							Class<?> c = null;			
							c = classLoader.loadClass("edu.northwestern.dasu.sandbox.applet.SandboxedActiveEngine");						
							SandboxedActiveEngineClass runnable = (SandboxedActiveEngineClass) 
									c.getConstructor(String[].class).newInstance(new Object[]{arguments}); 
							Thread t = new Thread(runnable);								
							ActiveEngines.put(engineId, runnable);
							
							//restart policy constraints
							Policy.getPolicy().refresh();
							
							t.start();
						}
						catch (Exception e) {

							LOGGER.info("AME: Downloaded experiment signature could not be verified or built, abort...");
							Writer writer = new StringWriter();
							PrintWriter printWriter = new PrintWriter(writer);
							e.printStackTrace(printWriter);
							String details = writer.toString();
							
							ReportableFact rf = new ReportableFact("ErrorEvent");
							rf.addContentsObject("report", "ExternalExperimentAborted");
							rf.addContentsObject("reason", "Downloaded experiment signature could not be verified or built, aborting..");
							rf.addContentsObject("stackTrace", details);
							rf.addContentsObject("arguments", Arrays.asList(arguments));						
							commitReportableFact(rf);
							
							//e.printStackTrace();
							AMEServer.AMECompleted(engineId, false);
						}
						
						iter.remove();
						
					}
				}	
				
				synchronized(notify) {
					notify.wait(5*1000);
				}

				
				Iterator<Entry<String, SandboxedActiveEngineClass>> iterAE = ActiveEngines.entrySet().iterator();
				while ( iterAE.hasNext() ) {
					Entry<String, SandboxedActiveEngineClass> entry = iterAE.next();
					if ( !entry.getValue().isAlive() ) {
						iterAE.remove();
						AMEServer.AMECompleted(entry.getKey(), true);
					}
					
				}

				LOGGER.info("AME: ActiveEngines: " + ActiveEngines);
				LOGGER.info("AME: ActiveEnginesRequest: " + ActiveEnginesRequest);

			}
			
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		LOGGER.info("AME: Server is not online, goodbye...");
		System.exit(0);
		
	}
	
	public static void shutDown(String reason) {
		
		ReportableFact rf = new ReportableFact("WatchdogTimer");
		rf.addContentsObject("jvmCpuUsage", profiler.getJvmCpuUsageList());
		rf.addContentsObject("dasuCpuUsageList", profiler.getDasuCpuUsageList());
		rf.addContentsObject("dasuMemoryUsageList", profiler.getMemoryUsage());
		rf.addContentsObject("report", "ExternalJvmShutdown");
		rf.addContentsObject("reason", reason);
		rf.addContentsObject("profileInterval", DasuConfiguration.getInstance().getResourceProfilerRecordInterval());
		rf.addContentsObject("limitUtilizationInterval", DasuConfiguration.getInstance().getResourceProfilerLimitUtilizationInterval());
	
		commitReportableFact(rf);
		shutdown = true;
		synchronized(notify) {
			notify.notify();
		}								

	}
	
	public static void commitReportableFact(ReportableFact rf) {
		
		try {
			AMEServer.commitReportableFact(rf);
		} catch (RemoteException e) {
			e.printStackTrace();
		}
	}
	
	private static boolean isShutdown() {
		return shutdown;
	}
	
}
